AsyncTaskExtension<P, R, T extends AsyncTask<P, R>> extension

extension for AsyncTask Iterable.

on

Properties

allTasksFinished → bool

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns true if all tasks are finished.
no setter
allTasksSubmitted → bool

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns true if all tasks were submitted for execution.
no setter
allTasksSuccessful → bool

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns true if all tasks are finished and successful.
no setter
errorTasks → List<T>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of tasks with errors.
no setter
finishedTasks → List<T>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of finished tasks.
no setter
hasIdleTask → bool

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns true if this collection has an idle task.
no setter
hasTaskWithError → bool

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns true if this collection has a task with error.
no setter
idleTasks → List<T>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of idle tasks.
no setter
notFinishedTasks → List<T>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of NOT finished tasks.
no setter
submittedTasks → List<T>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of submitted tasks.
no setter
successfulTasks → List<T>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of successful tasks.
no setter
tasksResults → List<R?>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of the current results.
no setter

Methods

executeAndWaitResults(AsyncExecutor executor) → Future<List<R>>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Executes the tasks with executor, waits the executions and returns the results.
executeAndWaitTasks(AsyncExecutor executor) → Future<List<T>>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Executes the tasks with executor, waits the executions and returns the tasks.
executeTasks(AsyncExecutor executor) → List<Future<R>>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Executes the tasks with executor.
tasksWithStatus(AsyncTaskStatus status) → List<T>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Returns a List of tasks with status.
waitResults({bool onlySubmitted = false}) → Future<List<R>>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Waits the tasks executions and returns a List of results.
waitTasks({bool onlySubmitted = false}) → Future<List<T>>

Available on Iterable<T>, provided by the AsyncTaskExtension extension

Waits the tasks executions and returns a List of waited tasks.