SharedPointerAddress class

Represents a SharedPointer.address, with its memoryAddress, type and parameters needed to re-instantiate a SharedPointer.

This is the actual instance that is shared between Isolates.

The method getPointer is capable to recreate the SharedPointer associated with this instance.

Implemented types

Constructors

SharedPointerAddress(int memoryAddress, [Type? type, List? parameters])

Properties

hashCode → int
The hash code for this object.
no setteroverride
memoryAddress → int
The real memory address for the associated SharedPointer's Pointer.
final
parameters → List?
The parameters need for getPointer recreate the SharedPointer instance.
final
requiresSerializationToBeShared → bool
Forces serialization and deserialization even when SharedData.noSerializationOnDartNative is true.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type?
The SharedPointer Type of this address.
final

Methods

computeSignature() → String
Computes the signature of this instance.
override
copy() → SharedPointerAddress
Creates a copy of this instance.
override
deserialize(List serial) → SharedPointerAddress
Deserializes serial to a instance of this type.
override
deserializeData(List serial) → SharedPointerAddress
Deserializes serial to D.
override
getPointer<T>() → SharedPointer<T>
Returns the SharedPointer for memoryAddress and type.
instantiate(SharedPointerAddress data) → SerializableData<SharedPointerAddress, List>
Creates a new instance with data.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → List
Serializes this instance to S.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override