SharedPointerMapped<T> class

A SharedPointerBytes mapped to generic reader/writer functions.

Inheritance

Constructors

SharedPointerMapped(int allocatedBytesLength, int bytesPerValue, SharedPointerMapWriter<T> writer, SharedPointerMapReader<T> reader)
SharedPointerMapped.fromAddress(int allocatedBytesLength, int bytesPerValue, SharedPointerMapWriter<T> writer, SharedPointerMapReader<T> reader, SharedPointerAddress address)

Properties

address ↔ SharedPointerAddress
latefinalinherited
allocatedBytesLength → int
Amount of bytes allocated by this instance.
finalinherited
byteData → ByteData
The ByteData of this Pointer memory.
no setterinherited
bytes → Uint8List
The Uint8List bytes viewer of this Pointer memory.
no setterinherited
bytesPerValue → int
Amount of bytes per value of this implementation.
finalinherited
endian → Endian
The endianness of this pointer.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initializeZeroed → bool
If true will initialize the instance with zeroes, removing any garbage in the allocated memory.
finalinherited
isClosed → bool
Returns true if this instance is closed (in the current Isolate).
no setterinherited
isEmpty → bool
Returns true if this instance is of length 0.
no setterinherited
isInitializer → bool
Returns true if this instance is the initializer instance, that actually allocated the pointer. Only the initializer instance can free the pointer.
no setterinherited
isNotEmpty → bool
Returns true if this instance is NOT of length 0.
no setterinherited
length ↔ int
Returns the fixed length of elements in this instance.
getter/setter pairinherited
reader → SharedPointerMapReader<T>
The reader Function.
final
requiresSerializationToBeShared → bool
Forces serialization and deserialization even when SharedData.noSerializationOnDartNative is true.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writer → SharedPointerMapWriter<T>
The writer Function.
final

Methods

checkClosed() → void
Checks if the instance is NOT closed, or throws a StateError.
inherited
computeSignature() → String
Computes the signature of this instance.
inherited
copy() → SharedPointerMapped<T>
Creates a copy of this instance.
override
deserialize(SharedPointerAddress serial) → SharedPointerMapped<T>
Deserializes serial to a instance of this type.
override
deserializeData(SharedPointerAddress serial) → SharedPointerMapped<T>
Deserializes serial to D.
override
free() → void
Closes this instance and calls malloc.free for the Pointer if this is the initializer instance. See isInitializer.
inherited
instantiate(SharedPointer<T> data) → SharedPointerMapped<T>
Creates a new instance with data.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → T?
Reads a value from the Pointer memory.
inherited
readAt(int index) → T?
Reads a value from index.
inherited
readFromByteData(ByteData byteData, int offset) → T?
Implementation to read a value from the byteData of this instance Pointer.
override
readNewValue({T? lastValue, Duration? interval, Duration? timeout, bool acceptsNullValue = true}) → FutureOr<T?>
Reads a new value, different from lastValue, performing a pooling with interval (default: 10ms) and a timeout (default: 10s) that checks for a new value if needed.
inherited
serialize() → SharedPointerAddress
Serializes this instance to S.
inherited
toString() → String
A string representation of this object.
inherited
write(T value) → void
Writes a value to the Pointer memory.
inherited
writeAt(int index, T value) → void
Writes a value at index.
inherited
writeToByteData(ByteData byteData, int offset, T value) → void
Implementation to write a value to the byteData of this instance Pointer.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited