SharedPointerUInt8List class

A SharedPointerBytes mapped to a Uint8List of fixed length.

Inheritance

Properties

address ↔ SharedPointerAddress
latefinalinherited
allocatedBytesLength → int
Amount of bytes allocated by this instance.
finalinherited
byteData → ByteData
The ByteData of this Pointer memory.
no setterinherited
bytes → Uint8List
The Uint8List bytes viewer of this Pointer memory.
no setterinherited
bytesPerValue → int
Amount of bytes per value of this implementation.
finalinherited
endian → Endian
The endianness of this pointer.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initializeZeroed → bool
If true will initialize the instance with zeroes, removing any garbage in the allocated memory.
finalinherited
isClosed → bool
Returns true if this instance is closed (in the current Isolate).
no setterinherited
isEmpty → bool
Returns true if this instance is of length 0.
no setterinherited
isInitializer → bool
Returns true if this instance is the initializer instance, that actually allocated the pointer. Only the initializer instance can free the pointer.
no setterinherited
isNotEmpty → bool
Returns true if this instance is NOT of length 0.
no setterinherited
length ↔ int
Returns the fixed length of elements in this instance.
getter/setter pairinherited
requiresSerializationToBeShared → bool
Forces serialization and deserialization even when SharedData.noSerializationOnDartNative is true.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkClosed() → void
Checks if the instance is NOT closed, or throws a StateError.
inherited
computeSignature() → String
Computes the signature of this instance.
inherited
copy() → SharedPointerUInt8List
Creates a copy of this instance.
override
deserialize(SharedPointerAddress serial) → SharedPointerUInt8List
Deserializes serial to a instance of this type.
override
deserializeData(SharedPointerAddress serial) → SharedPointerUInt8List
Deserializes serial to D.
override
free() → void
Closes this instance and calls malloc.free for the Pointer if this is the initializer instance. See isInitializer.
inherited
instantiate(SharedPointer<int> data) → SharedPointerUInt8List
Creates a new instance with data.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → int?
Reads a value from the Pointer memory.
inherited
readAt(int index) → int?
Reads a value from index.
inherited
readFromByteData(ByteData byteData, int offset) → int?
Implementation to read a value from the byteData of this instance Pointer.
override
readNewValue({int? lastValue, Duration? interval, Duration? timeout, bool acceptsNullValue = true}) → FutureOr<int?>
Reads a new value, different from lastValue, performing a pooling with interval (default: 10ms) and a timeout (default: 10s) that checks for a new value if needed.
inherited
serialize() → SharedPointerAddress
Serializes this instance to S.
inherited
sublist(int start, [int? end]) → Uint8List
toString() → String
A string representation of this object.
inherited
view() → Uint8List
write(int value) → void
Writes a value to the Pointer memory.
inherited
writeAt(int index, int value) → void
Writes a value at index.
inherited
writeToByteData(ByteData byteData, int offset, int value) → void
Implementation to write a value to the byteData of this instance Pointer.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited